@@ -1,5 +1,8 @@
 skip_conditionally()
 
+# Log
+system2("julia", '-e "using InteractiveUtils; println(versioninfo());"')
+
 #' @srrstats {G5.2} Appropriate message/warning/error tests are in `/tests/testthat`
 
 # test_that("Setup works", {
@@ -15,13 +18,13 @@ test_that("Setup with seed works (use 2 for testing)", {
 # test_that("Restart as default", {
 #   expect_true(jlmerclusterperm_setup(verbose = FALSE))
 # })
-
-test_that("Don't restart if FALSE", {
-  setup_is_ok <- julia_setup_ok()
-  if (setup_is_ok) {
-    expect_message(jlmerclusterperm_setup(restart = FALSE), "already running")
-  }
-})
+#
+# test_that("Don't restart if FALSE", {
+#   setup_is_ok <- julia_setup_ok()
+#   if (setup_is_ok) {
+#     expect_message(jlmerclusterperm_setup(restart = FALSE), "already running")
+#   }
+# })
 
 test_that("RNG initializes to seed=1 counter=0", {
   expect_equal(get_rng_seed(), 1)
